@@ -6,7 +6,7 @@ class NotifyUserList(models.Model):
     title = models.CharField(max_length=255, verbose_name='Название списка пользователей')
     created_at = models.DateTimeField(auto_now_add=True, verbose_name='Дата создания')
     user_groups = models.ManyToManyField(Group, blank=True, verbose_name='Группы пользователей')
-    mail_to_all = models.BooleanField(default=False, verbose_name='Отправить всем')
+    mail_to_all = models.BooleanField(default=False, verbose_name='Массовая рассылка для всех пользователей сайта')
 
     def __str__(self):
         return self.title
